@@ -2,6 +2,8 @@ import hashlib
 import hmac
 import json
 
+import arivo
+
 
 class WebhookError(Exception):
     pass
@@ -19,7 +21,7 @@ class Event(dict):
     pass
 
 
-def construct_event(payload, signature, secret):
+def construct_event(payload, signature, secret=None):
     if not isinstance(payload, bytes):
         raise InvalidPayload("payload must be of type 'bytes'")
     verify_signature(payload, signature, secret)
@@ -27,10 +29,13 @@ def construct_event(payload, signature, secret):
     return event
 
 
-def verify_signature(payload, signature, secret):
+def verify_signature(payload, signature, secret=None):
     if not signature:
         raise InvalidSignature
 
+    if secret is None:
+        secret = arivo.webhook_secret
+
     if hasattr(secret, "encode"):
         secret = secret.encode()
 
